==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm2015/lib/igc-geographic-proportional-symbol-series-component.js <==
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcSizeScaleComponent } from "igniteui-webcomponents-charts";
import { IgcBrushScaleComponent } from "igniteui-webcomponents-charts";
import { ScatterItemSearchMode_$type } from "igniteui-webcomponents-charts";
import { IgcAssigningScatterStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcAssigningScatterMarkerStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicMarkerSeriesComponent } from "./igc-geographic-marker-series-component";
import { GeographicProportionalSymbolSeries } from "./GeographicProportionalSymbolSeries";
import { getAllPropertyNames, toSpinal, ensureBool, ensureEnum, enumToString } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Series class for a geographic map with points marked at given locations.
 * This is the geographic equivalent of a ScatterSeries.
*/
export let IgcGeographicProportionalSymbolSeriesComponent = /*@__PURE__*/ (() => {
    class IgcGeographicProportionalSymbolSeriesComponent extends IgcGeographicMarkerSeriesComponent {
        createImplementation() {
            return new GeographicProportionalSymbolSeries();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
            this._assigningScatterStyle = null;
            this._assigningScatterStyle_wrapped = null;
            this._assigningScatterMarkerStyle = null;
            this._assigningScatterMarkerStyle_wrapped = null;
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicProportionalSymbolSeriesComponent._observedAttributesIgcGeographicProportionalSymbolSeriesComponent == null) {
                let names = getAllPropertyNames(IgcGeographicProportionalSymbolSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicProportionalSymbolSeriesComponent._observedAttributesIgcGeographicProportionalSymbolSeriesComponent = names;
            }
            return IgcGeographicProportionalSymbolSeriesComponent._observedAttributesIgcGeographicProportionalSymbolSeriesComponent;
        }
        static register() {
            if (!IgcGeographicProportionalSymbolSeriesComponent._isElementRegistered) {
                IgcGeographicProportionalSymbolSeriesComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcGeographicProportionalSymbolSeriesComponent.htmlTagName, IgcGeographicProportionalSymbolSeriesComponent);
            }
        }
        /**
         * Gets whether the series has only marker as visuals
        */
        get hasOnlyMarkers() {
            return this.i.dy;
        }
        /**
         * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
        */
        get latitudeMemberPath() {
            return this.i.v2;
        }
        set latitudeMemberPath(v) {
            this.i.v2 = v;
        }
        /**
         * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
        */
        get longitudeMemberPath() {
            return this.i.v4;
        }
        set longitudeMemberPath(v) {
            this.i.v4 = v;
        }
        /**
         * Gets or sets the radius mapping property for the current series object.
        */
        get radiusMemberPath() {
            return this.i.v9;
        }
        set radiusMemberPath(v) {
            this.i.v9 = v;
        }
        /**
         * Gets or sets the radius size scale for the bubbles.
        */
        get radiusScale() {
            const r = this.i.vg;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = IgcSizeScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        set radiusScale(v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.vg = null : this.i.vg = v.i;
        }
        /**
         * Gets or sets the Label mapping property for the current series object.
        */
        get labelMemberPath() {
            return this.i.v0;
        }
        set labelMemberPath(v) {
            this.i.v0 = v;
        }
        /**
         * Gets or sets the fill mapping property for the current series object.
        */
        get fillMemberPath() {
            return this.i.vs;
        }
        set fillMemberPath(v) {
            this.i.vs = v;
        }
        /**
         * Gets or sets the brush scale for the marker brush.
        */
        get fillScale() {
            const r = this.i.vd;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = IgcBrushScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        set fillScale(v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.vd = null : this.i.vd = v.i;
        }
        /**
         * Gets or sets the whether or not the FillScale uses global values of FillMemberPath of multiple series.
         * This setting applies only if multiple series are using the same FillScale.
        */
        get fillScaleUseGlobalValues() {
            return this.i.vk;
        }
        set fillScaleUseGlobalValues(v) {
            this.i.vk = ensureBool(v);
            this._a("fillScaleUseGlobalValues", this.i.vk);
        }
        /**
         * Gets or sets whether or not the marker outline should use FillScale like the marker fill does.
         * This setting applies only if the current series has a FillScale set and it overrides MarkerOutline setting.
        */
        get markerOutlineUsesFillScale() {
            return this.i.vn;
        }
        set markerOutlineUsesFillScale(v) {
            this.i.vn = ensureBool(v);
            this._a("markerOutlineUsesFillScale", this.i.vn);
        }
        /**
         * Gets or sets brightness of the marker outline. Using negative value will change marker outline to darker color and positive value will change marker outline to brighter color
         * Note you can use any values between minimum value of -1 (darkest outline) and maximum value of 1 (brightest outline)
        */
        get markerOutlineBrightness() {
            return this.i.vq;
        }
        set markerOutlineBrightness(v) {
            this.i.vq = +v;
            this._a("markerOutlineBrightness", this.i.vq);
        }
        /**
         * Gets or sets brightness of the marker fill. Using negative value will change marker fill to darker color and positive value will change marker fill to brighter color
         * Note you can use any values between minimum value of -1 (darkest fill) and maximum value of 1 (brightest fill)
        */
        get markerBrushBrightness() {
            return this.i.vp;
        }
        set markerBrushBrightness(v) {
            this.i.vp = +v;
            this._a("markerBrushBrightness", this.i.vp);
        }
        /**
         * Gets or sets the whether or not the RadiusScale uses global values of RadiusMemberPath of multiple series.
         * This setting applies only if multiple series are using the same RadiusScale.
        */
        get radiusScaleUseGlobalValues() {
            return this.i.vo;
        }
        set radiusScaleUseGlobalValues(v) {
            this.i.vo = ensureBool(v);
            this._a("radiusScaleUseGlobalValues", this.i.vo);
        }
        /**
         * Gets or sets whether this Scatter series should allow custom style overrides of its individual visuals.
        */
        get isCustomScatterStyleAllowed() {
            return this.i.vm;
        }
        set isCustomScatterStyleAllowed(v) {
            this.i.vm = ensureBool(v);
            this._a("isCustomScatterStyleAllowed", this.i.vm);
        }
        /**
         * Gets or sets whether this Scatter series should allow custom style overrides of its individual marker visuals.
        */
        get isCustomScatterMarkerStyleAllowed() {
            return this.i.vl;
        }
        set isCustomScatterMarkerStyleAllowed(v) {
            this.i.vl = ensureBool(v);
            this._a("isCustomScatterMarkerStyleAllowed", this.i.vl);
        }
        /**
         * Gets or sets the mode the series will use to find the closest point to the cursor.
        */
        get itemSearchMode() {
            return this.i.vf;
        }
        set itemSearchMode(v) {
            this.i.vf = ensureEnum(ScatterItemSearchMode_$type, v);
            this._a("itemSearchMode", enumToString(ScatterItemSearchMode_$type, this.i.vf));
        }
        /**
         * Gets or sets the threshold to use when searching for items using ItemSearchMode.
        */
        get itemSearchThreshold() {
            return this.i.vr;
        }
        set itemSearchThreshold(v) {
            this.i.vr = +v;
            this._a("itemSearchThreshold", this.i.vr);
        }
        findByName(name) {
            var baseResult = super.findByName(name);
            if (baseResult) {
                return baseResult;
            }
            if (this.radiusScale && this.radiusScale.name && this.radiusScale.name == name) {
                return this.radiusScale;
            }
            if (this.fillScale && this.fillScale.name && this.fillScale.name == name) {
                return this.fillScale;
            }
            return null;
        }
        _styling(container, component, parent) {
            super._styling(container, component, parent);
            this._inStyling = true;
            if (this.radiusScale && this.radiusScale._styling) {
                this.radiusScale._styling(container, component, this);
            }
            if (this.fillScale && this.fillScale._styling) {
                this.fillScale._styling(container, component, this);
            }
            this._inStyling = false;
        }
        /**
         * Event raised when Assigning Category Style
        */
        get assigningScatterStyle() {
            return this._assigningScatterStyle;
        }
        set assigningScatterStyle(ev) {
            if (this._assigningScatterStyle_wrapped !== null) {
                this.i.assigningScatterStyle = delegateRemove(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
                this._assigningScatterStyle_wrapped = null;
                this._assigningScatterStyle = null;
            }
            this._assigningScatterStyle = ev;
            this._assigningScatterStyle_wrapped = (o, e) => {
                let outerArgs = new IgcAssigningScatterStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeAssigningScatterStyle) {
                    this.beforeAssigningScatterStyle(this, outerArgs);
                }
                if (this._assigningScatterStyle) {
                    this._assigningScatterStyle(this, outerArgs);
                }
            };
            this.i.assigningScatterStyle = delegateCombine(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
            ;
        }
        /**
         * Event raised when Assigning Scatter Marker Style
        */
        get assigningScatterMarkerStyle() {
            return this._assigningScatterMarkerStyle;
        }
        set assigningScatterMarkerStyle(ev) {
            if (this._assigningScatterMarkerStyle_wrapped !== null) {
                this.i.assigningScatterMarkerStyle = delegateRemove(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
                this._assigningScatterMarkerStyle_wrapped = null;
                this._assigningScatterMarkerStyle = null;
            }
            this._assigningScatterMarkerStyle = ev;
            this._assigningScatterMarkerStyle_wrapped = (o, e) => {
                let outerArgs = new IgcAssigningScatterMarkerStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeAssigningScatterMarkerStyle) {
                    this.beforeAssigningScatterMarkerStyle(this, outerArgs);
                }
                if (this._assigningScatterMarkerStyle) {
                    this._assigningScatterMarkerStyle(this, outerArgs);
                }
            };
            this.i.assigningScatterMarkerStyle = delegateCombine(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
            ;
        }
    }
    IgcGeographicProportionalSymbolSeriesComponent._observedAttributesIgcGeographicProportionalSymbolSeriesComponent = null;
    IgcGeographicProportionalSymbolSeriesComponent.htmlTagName = "igc-geographic-proportional-symbol-series";
    IgcGeographicProportionalSymbolSeriesComponent._isElementRegistered = false;
    return IgcGeographicProportionalSymbolSeriesComponent;
})();

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm2015/lib/igc-geographic-proportional-symbol-series-component.js <==
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcSizeScaleComponent } from "igniteui-webcomponents-charts";
import { IgcBrushScaleComponent } from "igniteui-webcomponents-charts";
import { ScatterItemSearchMode_$type } from "igniteui-webcomponents-charts";
import { IgcAssigningScatterStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcAssigningScatterMarkerStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicMarkerSeriesComponent } from "./igc-geographic-marker-series-component";
import { GeographicProportionalSymbolSeries } from "./GeographicProportionalSymbolSeries";
import { getAllPropertyNames, toSpinal, ensureBool, ensureEnum, enumToString } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Series class for a geographic map with points marked at given locations.
 * This is the geographic equivalent of a ScatterSeries.
*/
export let IgcGeographicProportionalSymbolSeriesComponent = /*@__PURE__*/ (() => {
    class IgcGeographicProportionalSymbolSeriesComponent extends IgcGeographicMarkerSeriesComponent {
        createImplementation() {
            return new GeographicProportionalSymbolSeries();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
            this._assigningScatterStyle = null;
            this._assigningScatterStyle_wrapped = null;
            this._assigningScatterMarkerStyle = null;
            this._assigningScatterMarkerStyle_wrapped = null;
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicProportionalSymbolSeriesComponent._observedAttributesIgcGeographicProportionalSymbolSeriesComponent == null) {
                let names = getAllPropertyNames(IgcGeographicProportionalSymbolSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicProportionalSymbolSeriesComponent._observedAttributesIgcGeographicProportionalSymbolSeriesComponent = names;
            }
            return IgcGeographicProportionalSymbolSeriesComponent._observedAttributesIgcGeographicProportionalSymbolSeriesComponent;
        }
        static register() {
            if (!IgcGeographicProportionalSymbolSeriesComponent._isElementRegistered) {
                IgcGeographicProportionalSymbolSeriesComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcGeographicProportionalSymbolSeriesComponent.htmlTagName, IgcGeographicProportionalSymbolSeriesComponent);
            }
        }
        /**
         * Gets whether the series has only marker as visuals
        */
        get hasOnlyMarkers() {
            return this.i.ej;
        }
        /**
         * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
        */
        get latitudeMemberPath() {
            return this.i.yz;
        }
        set latitudeMemberPath(v) {
            this.i.yz = v;
        }
        /**
         * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
        */
        get longitudeMemberPath() {
            return this.i.y1;
        }
        set longitudeMemberPath(v) {
            this.i.y1 = v;
        }
        /**
         * Gets or sets the radius mapping property for the current series object.
        */
        get radiusMemberPath() {
            return this.i.y6;
        }
        set radiusMemberPath(v) {
            this.i.y6 = v;
        }
        /**
         * Gets or sets the radius size scale for the bubbles.
        */
        get radiusScale() {
            const r = this.i.yd;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = IgcSizeScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        set radiusScale(v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.yd = null : this.i.yd = v.i;
        }
        /**
         * Gets or sets the Label mapping property for the current series object.
        */
        get labelMemberPath() {
            return this.i.yx;
        }
        set labelMemberPath(v) {
            this.i.yx = v;
        }
        /**
         * Gets or sets the fill mapping property for the current series object.
        */
        get fillMemberPath() {
            return this.i.yp;
        }
        set fillMemberPath(v) {
            this.i.yp = v;
        }
        /**
         * Gets or sets the brush scale for the marker brush.
        */
        get fillScale() {
            const r = this.i.ya;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = IgcBrushScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        set fillScale(v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.ya = null : this.i.ya = v.i;
        }
        /**
         * Gets or sets the whether or not the FillScale uses global values of FillMemberPath of multiple series.
         * This setting applies only if multiple series are using the same FillScale.
        */
        get fillScaleUseGlobalValues() {
            return this.i.yh;
        }
        set fillScaleUseGlobalValues(v) {
            this.i.yh = ensureBool(v);
            this._a("fillScaleUseGlobalValues", this.i.yh);
        }
        /**
         * Gets or sets whether or not the marker outline should use FillScale like the marker fill does.
         * This setting applies only if the current series has a FillScale set and it overrides MarkerOutline setting.
        */
        get markerOutlineUsesFillScale() {
            return this.i.yk;
        }
        set markerOutlineUsesFillScale(v) {
            this.i.yk = ensureBool(v);
            this._a("markerOutlineUsesFillScale", this.i.yk);
        }
        /**
         * Gets or sets brightness of the marker outline. Using negative value will change marker outline to darker color and positive value will change marker outline to brighter color
         * Note you can use any values between minimum value of -1 (darkest outline) and maximum value of 1 (brightest outline)
        */
        get markerOutlineBrightness() {
            return this.i.yn;
        }
        set markerOutlineBrightness(v) {
            this.i.yn = +v;
            this._a("markerOutlineBrightness", this.i.yn);
        }
        /**
         * Gets or sets brightness of the marker fill. Using negative value will change marker fill to darker color and positive value will change marker fill to brighter color
         * Note you can use any values between minimum value of -1 (darkest fill) and maximum value of 1 (brightest fill)
        */
        get markerBrushBrightness() {
            return this.i.ym;
        }
        set markerBrushBrightness(v) {
            this.i.ym = +v;
            this._a("markerBrushBrightness", this.i.ym);
        }
        /**
         * Gets or sets the whether or not the RadiusScale uses global values of RadiusMemberPath of multiple series.
         * This setting applies only if multiple series are using the same RadiusScale.
        */
        get radiusScaleUseGlobalValues() {
            return this.i.yl;
        }
        set radiusScaleUseGlobalValues(v) {
            this.i.yl = ensureBool(v);
            this._a("radiusScaleUseGlobalValues", this.i.yl);
        }
        /**
         * Gets or sets whether this Scatter series should allow custom style overrides of its individual visuals.
        */
        get isCustomScatterStyleAllowed() {
            return this.i.yj;
        }
        set isCustomScatterStyleAllowed(v) {
            this.i.yj = ensureBool(v);
            this._a("isCustomScatterStyleAllowed", this.i.yj);
        }
        /**
         * Gets or sets whether this Scatter series should allow custom style overrides of its individual marker visuals.
        */
        get isCustomScatterMarkerStyleAllowed() {
            return this.i.yi;
        }
        set isCustomScatterMarkerStyleAllowed(v) {
            this.i.yi = ensureBool(v);
            this._a("isCustomScatterMarkerStyleAllowed", this.i.yi);
        }
        /**
         * Gets or sets the mode the series will use to find the closest point to the cursor.
        */
        get itemSearchMode() {
            return this.i.yc;
        }
        set itemSearchMode(v) {
            this.i.yc = ensureEnum(ScatterItemSearchMode_$type, v);
            this._a("itemSearchMode", enumToString(ScatterItemSearchMode_$type, this.i.yc));
        }
        /**
         * Gets or sets the threshold to use when searching for items using ItemSearchMode.
        */
        get itemSearchThreshold() {
            return this.i.yo;
        }
        set itemSearchThreshold(v) {
            this.i.yo = +v;
            this._a("itemSearchThreshold", this.i.yo);
        }
        findByName(name) {
            var baseResult = super.findByName(name);
            if (baseResult) {
                return baseResult;
            }
            if (this.radiusScale && this.radiusScale.name && this.radiusScale.name == name) {
                return this.radiusScale;
            }
            if (this.fillScale && this.fillScale.name && this.fillScale.name == name) {
                return this.fillScale;
            }
            return null;
        }
        _styling(container, component, parent) {
            super._styling(container, component, parent);
            this._inStyling = true;
            if (this.radiusScale && this.radiusScale._styling) {
                this.radiusScale._styling(container, component, this);
            }
            if (this.fillScale && this.fillScale._styling) {
                this.fillScale._styling(container, component, this);
            }
            this._inStyling = false;
        }
        /**
         * Event raised when Assigning Category Style
        */
        get assigningScatterStyle() {
            return this._assigningScatterStyle;
        }
        set assigningScatterStyle(ev) {
            if (this._assigningScatterStyle_wrapped !== null) {
                this.i.assigningScatterStyle = delegateRemove(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
                this._assigningScatterStyle_wrapped = null;
                this._assigningScatterStyle = null;
            }
            this._assigningScatterStyle = ev;
            this._assigningScatterStyle_wrapped = (o, e) => {
                let outerArgs = new IgcAssigningScatterStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeAssigningScatterStyle) {
                    this.beforeAssigningScatterStyle(this, outerArgs);
                }
                if (this._assigningScatterStyle) {
                    this._assigningScatterStyle(this, outerArgs);
                }
            };
            this.i.assigningScatterStyle = delegateCombine(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
            ;
        }
        /**
         * Event raised when Assigning Scatter Marker Style
        */
        get assigningScatterMarkerStyle() {
            return this._assigningScatterMarkerStyle;
        }
        set assigningScatterMarkerStyle(ev) {
            if (this._assigningScatterMarkerStyle_wrapped !== null) {
                this.i.assigningScatterMarkerStyle = delegateRemove(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
                this._assigningScatterMarkerStyle_wrapped = null;
                this._assigningScatterMarkerStyle = null;
            }
            this._assigningScatterMarkerStyle = ev;
            this._assigningScatterMarkerStyle_wrapped = (o, e) => {
                let outerArgs = new IgcAssigningScatterMarkerStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeAssigningScatterMarkerStyle) {
                    this.beforeAssigningScatterMarkerStyle(this, outerArgs);
                }
                if (this._assigningScatterMarkerStyle) {
                    this._assigningScatterMarkerStyle(this, outerArgs);
                }
            };
            this.i.assigningScatterMarkerStyle = delegateCombine(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
            ;
        }
    }
    IgcGeographicProportionalSymbolSeriesComponent._observedAttributesIgcGeographicProportionalSymbolSeriesComponent = null;
    IgcGeographicProportionalSymbolSeriesComponent.htmlTagName = "igc-geographic-proportional-symbol-series";
    IgcGeographicProportionalSymbolSeriesComponent._isElementRegistered = false;
    return IgcGeographicProportionalSymbolSeriesComponent;
})();
